<?php

class CC_Customer_Review_Meta_Box {

	private $screens = array(
		'cc_customer_review',
	);
	private $fields = array(
		array(
			'id' => 'status',
			'label' => 'Status',
			'type' => 'select',
			'options' => array(
				'pending' => 'pending',
				'approved' => 'approved',
				'denied' => 'denied',
			),
		),
		array(
			'id' => 'rating',
			'label' => 'Rating',
			'type' => 'select',
            'options' => array(
                '1' => '1 star',
                '2' => '2 stars',
                '3' => '3 stars',
                '4' => '4 stars',
                '5' => '5 stars'
            ),
		),
		array(
			'id' => 'name',
			'label' => 'Name',
			'type' => 'text',
		),
		array(
			'id' => 'email',
			'label' => 'Email',
			'type' => 'email',
		),
		array(
			'id' => 'sku',
			'label' => 'SKU',
			'type' => 'text',
		),
	);

	/**
	 * Class construct method. Adds actions to their respective WordPress hooks.
	 */
	public function __construct() {
		add_action( 'add_meta_boxes', array( $this, 'add_meta_boxes' ) );
		add_action( 'save_post', array( $this, 'save_post' ) );
	}

	/**
	 * Hooks into WordPress' add_meta_boxes function.
	 * Goes through screens (post types) and adds the meta box.
	 */
	public function add_meta_boxes() {
		foreach ( $this->screens as $screen ) {
			add_meta_box(
				'review-details',
				__( 'Review Details', 'cart66' ),
				array( $this, 'add_meta_box_callback' ),
				$screen,
				'advanced',
				'high'
			);
		}
	}

	/**
	 * Generates the HTML for the meta box
	 * 
	 * @param object $post WordPress post object
	 */
	public function add_meta_box_callback( $post ) {
		wp_nonce_field( 'review_details_data', 'review_details_nonce' );
		$this->generate_fields( $post );
	}

	/**
	 * Generates the field's HTML for the meta box.
	 */
	public function generate_fields( $post ) {
		$output = '';
		foreach ( $this->fields as $field ) {
			$label = '<label for="' . $field['id'] . '">' . $field['label'] . '</label>';
			$db_value = get_post_meta( $post->ID, 'review_details_' . $field['id'], true );
			switch ( $field['type'] ) {
				case 'select':
					CC_Log::write( 'Generating Select Box For Field ID: ' . $field['id'] . ' DBValue: ' . $db_value );
					$input = sprintf(
						'<select id="%s" name="%s">',
						$field['id'],
						$field['id']
					);
					foreach ( $field['options'] as $key => $value ) {
						// $field_value = !is_numeric( $key ) ? $key : $value;
						$field_value = $key;
						$input .= sprintf(
							'<option %s value="%s">%s</option>',
							$db_value == $field_value ? 'selected' : '',
							$field_value,
							$value
						);
					}
					$input .= '</select>';
					break;
				default:
					$input = sprintf(
						'<input %s id="%s" name="%s" type="%s" value="%s">',
						$field['type'] !== 'color' ? 'class="regular-text"' : '',
						$field['id'],
						$field['id'],
						$field['type'],
						$db_value
					);
			}
			$output .= $this->row_format( $label, $input );
		}
		
		echo '<table class="form-table"><tbody>' . $output . '</tbody></table>';
	}

	/**
	 * Generates the HTML for table rows.
	 */
	public function row_format( $label, $input ) {
		return sprintf(
			'<tr><th scope="row">%s</th><td>%s</td></tr>',
			$label,
			$input
		);
	}
	/**
	 * Hooks into WordPress' save_post function
	 */
	public function save_post( $post_id ) {
		if ( ! isset( $_POST['review_details_nonce'] ) )
			return $post_id;

		$nonce = $_POST['review_details_nonce'];
		if ( !wp_verify_nonce( $nonce, 'review_details_data' ) )
			return $post_id;

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
			return $post_id;

		foreach ( $this->fields as $field ) {
			if ( isset( $_POST[ $field['id'] ] ) ) {
				switch ( $field['type'] ) {
					case 'email':
						$_POST[ $field['id'] ] = sanitize_email( $_POST[ $field['id'] ] );
						break;
					case 'text':
						$_POST[ $field['id'] ] = sanitize_text_field( $_POST[ $field['id'] ] );
						break;
				}
				update_post_meta( $post_id, 'review_details_' . $field['id'], $_POST[ $field['id'] ] );
			} else if ( $field['type'] === 'checkbox' ) {
				update_post_meta( $post_id, 'review_details_' . $field['id'], '0' );
			}
		}
	}
}
